@@ -79,7 +79,7 @@ impl RangeBounds<usize> for Error {
 
 		match &self.span_maybe {
 
-			Some(span) => Bound::Included(&span.range.start),
+			Some(span) => Bound::Included(&span.start.index),
 			None => Bound::Unbounded
 
 		}
@@ -90,7 +90,7 @@ impl RangeBounds<usize> for Error {
 		
 		match &self.span_maybe {
 	
-			Some(span) => Bound::Included(&span.range.end),
+			Some(span) => Bound::Included(&span.end.index),
 			None => Bound::Unbounded
 	
 		}		
@@ -169,7 +169,7 @@ impl Display for Error {
 				let span = error.span_maybe.clone().unwrap();
 				let string = span.string();
 				let range = span.range(); 
-				let lines = span.lines.clone();
+				let lines = span.start.line .. span.end.line;
 				let mut current_line = 0;
 
 				let mut should_write_line_indicator = true;
@@ -243,22 +243,20 @@ impl Display for Error {
 	
 }
 
-
-
 impl Ord for Error {
 
 	fn cmp(&self, other: &Self) -> std::cmp::Ordering {
 		
 		let self_start = match &self.span_maybe {
 
-			Some(span) => span.range.start,
+			Some(span) => span.start.index,
 			None => 0
 
 		};
 
 		let other_start = match &other.span_maybe {
 
-			Some(span) => span.range.start,
+			Some(span) => span.start.index,
 			None => 0
 
 		};
