@@ -18,7 +18,9 @@ use std::fmt::Debug;
 mod level;
 mod error;
 mod span;
+mod boundary;
 
+pub use boundary::*;
 pub use span::*;
 pub use error::*;
 pub use level::*;
@@ -37,14 +39,14 @@ mod tests {
 		let string = " first asdfasdf \r\n\t second \n third ";
 	
 		let span = Span::new(string, 1..6);
-		let mut warning = Error::new(Some(span.clone()), Level::Warning, "This is a warning.");
+		let warning = Error::new(Some(span.clone()), Level::Warning, "This is a warning.");
 	
-		let other_span = Span::new(string, 6..10);
-		let error = Error::new(Some(other_span), Level::Error, "Haha yeah.");
+		let other_span = Span::new(string, 21..23);
+		let mut error = Error::new(Some(other_span.clone()), Level::Error, "Haha nope.");
 		
-		warning += error;
+		error += warning;
 
-		println!("{warning}");
+		println!("{error}")
 		
 	}
 
