@@ -4,20 +4,31 @@ use super::*;
 #[derive(Clone, PartialEq, Eq, Hash)]
 pub struct Span {
 
-	pub(crate) lines: Range<usize>,
-	pub(crate) columns: Range<usize>,
-	pub(crate) range: Range::<usize>,
-	pub(crate) string: Rc::<str>
+	pub(crate) start: Boundary,
+	pub(crate) end: Boundary,
+	pub(crate) string: Rc::<str>,
 
 }
 
-
 impl Span {
 
-	/// Assigns `self.range.end`.
-	pub fn end(&mut self, end: usize) {
+	/// A Boun
+	pub fn start(&self) -> Boundary {
 		
-		self.range.end = end;
+		self.start
+		
+	}
+	
+	pub fn end(&self) -> Boundary {
+
+		self.end
+
+	}
+
+	/// Assigns `self.end`.
+	pub fn reassign_end(&mut self, end: usize) {
+		
+		self.end = Boundary::new(self.string(), end);
 
 	}
 
@@ -38,54 +49,20 @@ impl Span {
 	/// The indices of `self.slice()`.
 	pub fn range(&self) -> Range<usize> {
 
-		self.range.clone()
+		self.start.index .. self.end.index
 
 	}
 
 	/// Constructs a new `Span`.
 	pub fn new(string: &str, range: Range<usize>) -> Span {
-		
-		let mut current_line = 1;
-		let mut current_column = 1;
 
-		let mut lines = Range::default();
-		let mut columns = Range::default();
-		
-		for (index, character) in string.char_indices() {
-
-			if range.start == index {
-
-				lines.start = current_line;
-				columns.start = current_column;
-
-			}
-
-			else if range.end == index {
-
-				lines.end = current_line + 1;
-				columns.end = current_column;
-				break;
-
-			}
-
-			if character == '\n' {
-
-				current_line += 1;
-				current_column = 1;
-
-			} 
-			
-			else {
-
-				current_column += 1;
-
-			}
-
-		}
+		let start = Boundary::new(string, range.start);
+		let mut end = Boundary::new(string, range.end);
+		end.line += 1;
 
 		let string = Rc::from(string);
 
-		Self { string, range, lines, columns }
+		Self { string, start, end }
 		
 	}
 
@@ -96,10 +73,10 @@ impl Debug for Span {
 	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
 		
 		let slice = &self.slice();
-		let start = self.range.start;
-		let end = self.range.end;
-		let line_start = self.lines.start;
-		let line_end = self.lines.end;
+		let start = self.start.index;
+		let end = self.end.index;
+		let line_start = self.start.line;
+		let line_end = self.end.line;
 		
 		write!(f, "[{slice:?}, {start}..{end}, lines {line_start}..{line_end}]")
 
@@ -111,7 +88,7 @@ impl Ord for Span {
 
 	fn cmp(&self, other: &Self) -> std::cmp::Ordering {
 		
-		self.range.start.cmp(&other.range.start)
+		self.start.index.cmp(&other.start.index)
 
 	}
 
@@ -121,7 +98,7 @@ impl PartialOrd for Span {
 
 	fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
 		
-		self.range.start.partial_cmp(&other.range.start)
+		self.start.index.partial_cmp(&other.start.index)
 
 	}
 
